@@ -47,21 +47,6 @@ from ..lib.tools import terminalfit, get_terminal_size, documentation, lookahead
 from ..lib.frame import Framed, Chunk
 
 
-def _retrofitted(cls: Union[type, Any]) -> bool:
-    if not isinstance(cls, type):
-        cls = cls.__class__
-    bases = cls.__mro__[1:]
-    if len(bases) == 1:
-        return False
-    for base in bases:
-        try:
-            if cls.interface.__func__ is not base.interface.__func__:
-                return False
-        except AttributeError:
-            pass
-    return True
-
-
 class ArgparseError(ValueError):
     """
     This custom exception type is thrown from the custom argument parser of
@@ -153,31 +138,59 @@ class arg(Argument):
     """
 
     class delete: pass
+    class omit: pass
 
     def __init__(
         self, *args: str,
+            action   : Union[omit, str]           = omit, # noqa
+            choices  : Union[omit, Iterable[Any]] = omit, # noqa
+            const    : Union[omit, Any]           = omit, # noqa
+            default  : Union[omit, Any]           = omit, # noqa
+            dest     : Union[omit, str]           = omit, # noqa
+            help     : Union[omit, str]           = omit, # noqa
+            metavar  : Union[omit, str]           = omit, # noqa
+            nargs    : Union[omit, int, str]      = omit, # noqa
+            required : Union[omit, bool]          = omit, # noqa
+            type     : Union[omit, type]          = omit, # noqa
             group    : Optional[str]              = None, # noqa
-            action   : Optional[str]              = None, # noqa
-            choices  : Optional[Iterable[Any]]    = None, # noqa
-            const    : Optional[Any]              = None, # noqa
-            default  : Optional[Any]              = None, # noqa
-            dest     : Optional[str]              = None, # noqa
-            help     : Optional[str]              = None, # noqa
-            metavar  : Optional[str]              = None, # noqa
-            nargs    : Optional[Union[int, str]]  = None, # noqa
-            required : Optional[bool]             = None, # noqa
-            type     : Optional[type]             = None, # noqa
             guess    : bool                       = False # noqa
     ) -> None:
         kwargs = dict(action=action, choices=choices, const=const, default=default, dest=dest,
             help=help, metavar=metavar, nargs=nargs, required=required, type=type)
-        kwargs = {key: value for key, value in kwargs.items() if value is not None}
+        kwargs = {key: value for key, value in kwargs.items() if value is not arg.omit}
         self.group = group
         self.guess = guess
         super().__init__(*args, **kwargs)
 
+    def update_help(self):
+        if 'help' not in self.kwargs:
+            return
+        formatting = {}
+        choices = self.kwargs.get('choices', None)
+        if choices is not None:
+            formatting.update(choices=', '.join(self.kwargs['choices']))
+        default = self.kwargs.get('default', None)
+        if default is not None:
+            try:
+                formatting.update(default=F'H:{default.hex()}')
+            except AttributeError:
+                formatting.update(default=str(default))
+        try:
+            self.kwargs['help'] = self.kwargs['help'].format(**formatting)
+        except Exception:
+            pass
+
+    def __rmatmul__(self, method):
+        self.update_help()
+        return super().__rmatmul__(method)
+
     @staticmethod
-    def switch(*args: str, group: Optional[str] = None, help: Optional[str] = None, dest: Optional[str] = None, off=False) -> Argument:
+    def switch(
+        *args: str, off=False,
+        help : Union[omit, str] = omit,
+        dest : Union[omit, str] = omit,
+        group: Optional[str] = None,
+    ) -> Argument:
         """
         A convenience method to add argparse arguments that change a boolean value from True to False or
         vice versa. By default, a switch will have a False default and change it to True when specified.
@@ -187,47 +200,49 @@ class arg(Argument):
     @staticmethod
     def number(
         *args: str,
-        group : Optional[str] = None,
-        bound : Optional[Tuple[int, int]] = None,
-        help  : Optional[str] = None,
-        dest  : Optional[str] = None,
+        bound: Union[omit, Tuple[int, int]] = omit,
+        help : Union[omit, str] = omit,
+        dest : Union[omit, str] = omit,
+        group: Optional[str] = None,
     ) -> Argument:
         """
         Used to add argparse arguments that contain a number.
         """
         nt = number
-        if bound is not None:
+        if bound is not arg.omit:
             lower, upper = bound
             nt = nt[lower:upper]
         return arg(*args, group=group, help=help, dest=dest, type=nt, metavar='N')
 
     @staticmethod
-    def option(*args: str, choices: Enum, group: Optional[str] = None, help: Optional[str] = None, dest: Optional[str] = None) -> Argument:
+    def option(
+        *args: str, choices: Enum,
+        help : Union[omit, str] = omit,
+        dest : Union[omit, str] = omit,
+        metavar: Optional[str] = None,
+        group: Optional[str] = None,
+    ) -> Argument:
         """
         Used to add argparse arguments with a fixed set of options, based on an enumeration.
         """
         cnames = [c.name for c in choices]
-        return arg(*args, group=group, help=help.format(choices=', '.join(cnames)),
-            metavar=choices.__name__, dest=dest, choices=[c.value for c in choices], type=choices.__getitem__)
-
-    @staticmethod
-    def help(msg: str) -> Argument:
-        return arg(help=msg)
+        metavar = metavar or choices.__name__
+        return arg(*args, group=group, help=help, metavar=metavar, dest=dest, choices=cnames, type=str)
 
     @staticmethod
     def choice(
         *args: str, choices : List[str],
+        help    : Union[omit, str] = omit,
+        metavar : Union[omit, str] = omit,
+        dest    : Union[omit, str] = omit,
+        nargs   : Union[omit, int, str] = omit,
         group   : Optional[str] = None,
-        help    : Optional[str] = None,
-        metavar : Optional[str] = None,
-        dest    : Optional[str] = None,
-        nargs   : Optional[Union[int, str]] = None,
     ):
         """
         Used to add argparse arguments with a fixed set of options, based on a list of strings.
         """
         return arg(*args, group=group, type=str, metavar=metavar, nargs=nargs,
-            dest=dest, help=help.format(choices=', '.join(choices)), choices=choices)
+            dest=dest, help=help, choices=choices)
 
     @property
     def positional(self) -> bool:
@@ -258,6 +273,9 @@ class arg(Argument):
         parameter. This guess is based on the annotation, name, and default value.
         """
 
+        def needs_type(item):
+            return item.get('action', 'store') == 'store'
+
         def get_argp_type(annotation_type):
             if issubclass(annotation_type, (bytes, bytearray, memoryview)):
                 return multibin
@@ -283,7 +301,7 @@ class arg(Argument):
                 guessed_kwd_args['guess'] = False
                 guessed_kwd_args['group'] = pt.annotation.group
             elif isinstance(pt.annotation, type):
-                if not issubclass(pt.annotation, bool):
+                if not issubclass(pt.annotation, bool) and needs_type(guessed_kwd_args):
                     guessed_kwd_args.update(type=get_argp_type(pt.annotation))
                 elif not isinstance(default, bool):
                     raise ValueError('Default value for boolean arguments must be provided.')
@@ -313,7 +331,7 @@ class arg(Argument):
         if default is not pt.empty:
             if isinstance(default, bool):
                 guessed_kwd_args['action'] = 'store_false' if default else 'store_true'
-            elif 'type' not in guessed_kwd_args:
+            elif needs_type(guessed_kwd_args) and 'type' not in guessed_kwd_args:
                 guessed_kwd_args['type'] = get_argp_type(type(default))
 
         return cls(*guessed_pos_args, **guessed_kwd_args)
@@ -346,12 +364,6 @@ class arg(Argument):
         self.guess = self.guess and them.guess
         self.group = self.group or them.group
 
-    def __or__(self, them: Argument) -> Argument:
-        clone = self.__copy__()
-        clone.kwargs.update(self.kwargs)
-        clone.merge_args(them)
-        return clone
-
     def __copy__(self) -> Argument:
         cls = self.__class__
         clone = cls.__new__(cls)
@@ -411,7 +423,7 @@ class Executable(type):
         args = ArgumentSpecification() if args is None else args
         temp = ArgumentSpecification()
 
-        exposed = [pt.name for pt in skipfirst(parameters.values())]
+        exposed = [pt.name for pt in skipfirst(parameters.values()) if pt.kind != pt.VAR_KEYWORD]
         # The arguments are added in reverse order to the argument parser later.
         # This is done to have a more intuitive use of decorator based argument configuration.
         exposed.reverse()
@@ -433,8 +445,11 @@ class Executable(type):
                 continue
             if not known.positional:
                 known.merge_args(guess)
-            for k in guess.kwargs:
-                known.kwargs.setdefault(k, guess.kwargs[k])
+            for k, v in guess.kwargs.items():
+                if k == 'default':
+                    known.kwargs[k] = v
+                else:
+                    known.kwargs.setdefault(k, v)
 
         for name in exposed:
             args.move_to_end(name)
@@ -447,10 +462,12 @@ class Executable(type):
             elif not any(a.startswith('--') for a in known.args):
                 flagname = known.destination.replace('_', '-')
                 known.args.append(F'--{flagname}')
-            if known.kwargs.get('action', '').startswith('store_'):
+            action = known.kwargs.get('action', 'store')
+            if action.startswith('store_'):
                 known.kwargs.pop('default', None)
                 continue
-            known.kwargs.setdefault('type', multibin)
+            if action == 'store':
+                known.kwargs.setdefault('type', multibin)
         return args
 
     def __new__(mcs, name, bases, nmspc, abstract=False):
@@ -497,18 +514,8 @@ class Executable(type):
         parameters = inspect.signature(cls.__init__).parameters
         cls.argspec = ArgumentSpecification()
 
-        if _retrofitted(cls):
-            if not bases:
-                raise TypeError(
-                    F'Unexpected empty MRO for {cls.__name__}: You should not use the Executable '
-                    F'metaclass directly, instead you should inherit from Unit.'
-                )
+        if bases:
             parent = bases[0]
-            if not _retrofitted(parent) and cls.__init__ is parent.__init__:
-                @wraps(cls.__init__)
-                def __init__stub_(self): parent.__init__(self)
-                cls.__init__ = __init__stub_
-                parameters = dict(self=None)
             for key, value in parent.argspec.items():
                 if not value.guess and key in parameters:
                     cls.argspec[key] = value.__copy__()
@@ -549,7 +556,7 @@ class Executable(type):
                     F'already executed: {Executable.Entry}'
                 )
             else:
-                Executable.Entry = cls.__name__
+                Executable.Entry = cls.name
                 cls.run()
 
     def __getitem__(cls, other):
@@ -571,13 +578,17 @@ class Executable(type):
         return hasattr(cls, 'reverse')
 
     @property
-    def codec(self) -> str:
+    def codec(cls) -> str:
         """
         The default codec for encoding textual information between units.
         The value of this property is hardcoded to `UTF8`.
         """
         return 'UTF8'
 
+    @property
+    def name(cls) -> str:
+        return cls.__name__.replace('_', '-')
+
 
 class LogLevel(IntEnum):
     """
@@ -704,6 +715,10 @@ class Unit(metaclass=Executable, abstract=True):
     def codec(self) -> str:
         return self.__class__.codec
 
+    @property
+    def name(self) -> str:
+        return self.__class__.name
+
     @property
     def log_level(self) -> LogLevel:
         """
@@ -1000,18 +1015,13 @@ class Unit(metaclass=Executable, abstract=True):
                 return codecs.decode(x, cls.codec, errors='backslashreplace')
             return str(x)
         message = ' '.join(transform(msg) for msg in messages)
-        sys.stderr.write(F'{cls.__name__}: {message}\n')
+        sys.stderr.write(F'{cls.name}: {message}\n')
 
     @classmethod
-    def interface(cls, argp: ArgumentParser) -> ArgumentParser:
+    def _interface(cls, argp: ArgumentParser) -> ArgumentParser:
         """
         Receives a reference to an `ArgumentParser` object. This parser will be used to parse
-        the command line for this unit into the member variable called `args`. Previously, it
-        was requested that children of `refinery.units.Unit` override this method to customize
-        their command line interface. This is now deprecated in favor of using initialization
-        methods and `refinery.units.arg` decorators to customize the parser. The current goal
-        is to remove `refinery.units.Unit.interface` in a future version when retrofitting the
-        old units to the new `refinery.units.arg` based interface is complete.
+        the command line for this unit into the member variable called `args`.
         """
         base = argp.add_argument_group('generic options')
 
@@ -1061,7 +1071,7 @@ class Unit(metaclass=Executable, abstract=True):
                     action.required = False
                     if callable(getattr(action, 'type', None)):
                         value = keywords[action.dest]
-                        if isinstance(value, str) and action.type is not str:
+                        if value is not None and isinstance(value, str) and action.type is not str:
                             keywords[action.dest] = action.type(keywords[action.dest])
 
                 return super()._add_action(RememberOrder())
@@ -1132,17 +1142,17 @@ class Unit(metaclass=Executable, abstract=True):
                     return ', '.join(parts)
 
         argp = ArgumentParserWithKeywordHooks(
-            prog=cls.__name__.replace('_', '-'),
+            prog=cls.name,
             description=documentation(cls),
             formatter_class=LineWrapRawTextHelpFormatter,
             add_help=False
         )
 
         argp.set_defaults(nesting=0)
-        return cls.interface(argp)
+        return cls._interface(argp)
 
     @staticmethod
-    def superinit(super, **keywords):
+    def superinit(spc, **keywords):
         """
         This function uses `refinery.lib.tools.autoinvoke` to call the `__init__` function of `super` with
         by taking all required parameters from `keywords`, ignoring the rest. Calling
@@ -1153,16 +1163,19 @@ class Unit(metaclass=Executable, abstract=True):
         manually. This is a convenience feature which reduces code bloat when many parameters have to be
         forwarded, see e.g. `refinery.units.pattern.carve.carve` for an example.
         """
+        args = inspect.signature(spc.__thisclass__.__init__).parameters
+        keep = list(skipfirst(args))
+        junk = [a for a in keywords if a not in keep]
+        for j in junk: del keywords[j]
+        for a in args.values():
+            if a.kind is a.VAR_KEYWORD:
+                keywords.update(keywords.pop(a.name, {}))
         try:
-            if super.__init__.__func__ is Unit.__init__:
-                return super.__init__(**{
-                    name: value for name, value in keywords.items()
-                    if name != 'self' and not name.startswith('_')
-                })
+            if spc.__init__.__func__ is Unit.__init__:
+                return spc.__init__(**keywords)
         except AttributeError:
             pass
-
-        return autoinvoke(super.__init__, keywords)
+        return autoinvoke(spc.__init__, keywords)
 
     @classmethod
     def assemble(cls, *args, **keywords):
@@ -1176,8 +1189,7 @@ class Unit(metaclass=Executable, abstract=True):
         args = argp.parse_args()
 
         try:
-            if _retrofitted(cls): unit = autoinvoke(cls, args.__dict__)
-            else: unit = cls(DelayedArgumentProxy(args, argp.order))
+            unit = autoinvoke(cls, args.__dict__)
         except ValueError as E:
             argp.error(str(E))
 
@@ -1207,36 +1219,25 @@ class Unit(metaclass=Executable, abstract=True):
         clone.args = self.args.__copy__()
         return clone
 
-    def __init__(self, *args, **keywords):
+    def __init__(self, **keywords):
         self._buffer = B''
         self._source = None
         self._target = None
         self._framed = None
         self._chunks = None
 
-        if _retrofitted(self):
-            assert not args, (
-                'Retrofitted units may not call the Unit base constructor with positional arguments.'
-            )
-            keywords.update(dict(
-                dtiming=False,
-                nesting=0,
-                reverse=False,
-                squeeze=False,
-                devnull=False,
-                verbose=LogLevel.DETACHED,
-                quiet=False,
-            ))
-            # Since Python 3.6, functions always preserve the order of the keyword
-            # arguments passed to them (see PEP 468).
-            self.args = DelayedArgumentProxy(
-                Namespace(**keywords), list(keywords))
-        elif not keywords and len(args) == 1 and isinstance(args[0], DelayedArgumentProxy):
-            self.args = args[0]
-        else:
-            keywords.setdefault('verbose', -1)
-            argp = self.argparser(*args, **keywords)
-            self.args = DelayedArgumentProxy(argp.parse_args(), argp.order)
+        keywords.update(dict(
+            dtiming=False,
+            nesting=0,
+            reverse=False,
+            squeeze=False,
+            devnull=False,
+            verbose=LogLevel.DETACHED,
+            quiet=False,
+        ))
+        # Since Python 3.6, functions always preserve the order of the keyword
+        # arguments passed to them (see PEP 468).
+        self.args = DelayedArgumentProxy(Namespace(**keywords), list(keywords))
 
     @classmethod
     def run(cls, argv=None, stream=None) -> None:
