@@ -29,7 +29,7 @@ class CipherExecutable(Executable):
 
 class CipherUnit(Unit, metaclass=CipherExecutable, abstract=True):
 
-    def __init__(self, key: arg.help('The encryption key.'), **keywords):
+    def __init__(self, key: arg(help='The encryption key.'), **keywords):
         super().__init__(key=key, **keywords)
 
     @property
@@ -111,8 +111,8 @@ class BlockCipherUnitBase(CipherUnit, abstract=True):
 
     def reverse(self, data: ByteString) -> ByteString:
         padding = self.args.padding[0]
+        self.log_info('padding method:', padding)
         if padding != 'RAW':
-            self.log_info('padding method:', padding)
             data = pad(data, self.blocksize, padding.lower())
         return super().reverse(data)
 
@@ -151,7 +151,7 @@ class StandardCipherExecutable(CipherExecutable):
             modes = extract_options(cipher)
             if not modes:
                 raise RefineryCriticalException(
-                    F'The cipher {cipher.__name__} is a block cipher module, '
+                    F'The cipher {cipher.name} is a block cipher module, '
                     F'but no cipher block mode constants were found.'
                 )
             cls.modespec = OptionFactory(modes, ignorecase=True)
@@ -179,7 +179,7 @@ class StandardCipherUnit(CipherUnit, metaclass=StandardCipherExecutable):
 
 class StandardBlockCipherUnit(BlockCipherUnitBase, StandardCipherUnit):
 
-    def __init__(self, mode, key, iv=None, padding=None):
+    def __init__(self, mode, key, iv=B'', padding=None):
         super().__init__(key=key, iv=iv, padding=padding, mode=self.modespec(mode))
 
     def _get_cipher_instance(self, **optionals) -> Any:
