@@ -10,7 +10,7 @@ class ps1str(Unit):
     """
     Escapes and unescapes PowerShell strings.
     """
-    _UNESCAPE = {
+    UNESCAPE = {
         '`0': '\0',
         '`a': '\a',
         '`b': '\b',
@@ -23,8 +23,9 @@ class ps1str(Unit):
         "`'": '\'',
         '`"': '\"',
     }
-    _ESCAPE = {
-        '`': '``',
+    ESCAPE = {
+        '`' : '``',
+        '$' : '`$',
         '\0': '`0',
         '\a': '`a',
         '\b': '`b',
@@ -51,13 +52,18 @@ class ps1str(Unit):
 
         def unescape(match):
             string = match.group(0)
-            return self._UNESCAPE.get(string, string[1:])
+            return self.UNESCAPE.get(string, string[1:])
 
-        return re.sub('`.', unescape, data).replace(2 * quote, quote)
+        if quote == '"':
+            if re.search(R'(?<!`)\$(?=[\w\(\{\$\?\^:])', data):
+                self.log_warn(F'Loss of information: double quoted string contains variable substitutions.')
+            data = re.sub('`.', unescape, data)
+
+        return data.replace(quote + quote, quote)
 
     @unicoded
     def reverse(self, data):
-        def escape(match):
-            string = match.group(0)
-            return self._ESCAPE[string]
-        return "'{}'".format(re.sub(R'[`\0\a\b\f\n\r\t\v\'\"]', escape, data))
+        def escaper(match):
+            char = match[0]
+            return ps1str.ESCAPE.get(char, char)
+        return '"{}"'.format(re.sub(R'''[\x00\x07-\x0D`$'"]''', escaper, data))
