@@ -23,17 +23,16 @@ class EndOfStringNotFound(ValueError):
         super().__init__('end of string could not be determined')
 
 
-class PathExtractorUnit(Unit):
+class PathExtractorUnit(Unit, abstract=True):
 
-    @classmethod
-    def interface(cls, argp):
-        argp.add_argument('paths', metavar='path', nargs='*', default=['*'], type=pathspec, help=(
+    def __init__(self, *paths: arg(
+        metavar='path', nargs='*', default=['*'], type=pathspec, help=(
             'A path from which data is to be extracted. Each item is returned '
-            ' as a separate output of this unit. Paths may contain wildcards. '
+            'as a separate output of this unit. Paths may contain wildcards. '
             'The default is a single asterix, which means that every item will '
-            'be extracted.'
-        ))
-        return super().interface(argp)
+            'be extracted.')
+    )):
+        super().__init__(paths=paths)
 
     def _check_reachable(self, path: str) -> bool:
         for pattern in self.args.path:
@@ -46,7 +45,7 @@ class PathExtractorUnit(Unit):
         return any(fnmatch.fnmatch(path, pattern) for pattern in self.args.paths)
 
 
-class MemoryExtractorUnit(Unit):
+class MemoryExtractorUnit(Unit, abstract=True):
 
     def __init__(
         self,
