@@ -3,7 +3,7 @@
 import pefile
 from fnmatch import fnmatch
 
-from ... import Unit
+from ... import arg, Unit
 
 
 class rsrc:
@@ -70,12 +70,11 @@ class perc(Unit):
     Extract PE file resources.
     """
 
-    @classmethod
-    def interface(cls, argp):
-        argp.add_argument(metavar='entry', dest='entries', type=rsrc, nargs='*',
-            help='A resource path for the resource to be extracted. May contain numeric '
-                 'literals and name strings with wildcards.')
-        return super().interface(argp)
+    def __init__(self, *entries: arg(metavar='entry', type=rsrc, help=(
+        'A resource path for the resource to be extracted. May contain numeric '
+        'literals and name strings with wildcards.'
+    ))):
+        super().__init__(entries=entries)
 
     def _match(self, level, needle, e):
         if e.id == needle or str(e.id) == needle:
@@ -110,8 +109,8 @@ class perc(Unit):
         if not self.args.entries:
             yield from self._search(pe, pe.DIRECTORY_ENTRY_RESOURCE, [])
             return
-        for arg in self.args.entries:
-            while len(arg.needles) <= 3:
-                self.log_info('searching pattern:', str(arg))
-                yield from self._search(pe, pe.DIRECTORY_ENTRY_RESOURCE, arg.needles)
-                arg = arg.relax()
+        for entry in self.args.entries:
+            while len(entry.needles) <= 3:
+                self.log_info('searching pattern:', str(entry))
+                yield from self._search(pe, pe.DIRECTORY_ENTRY_RESOURCE, entry.needles)
+                entry = entry.relax()
